@@ -1,16 +1,15 @@
 from nomenklatura.dataset import Dataset
 from nomenklatura.entity import CompositeEntity
 from nomenklatura.resolver import Resolver
-from nomenklatura.loader import Loader, FileLoader, MemoryLoader
+from nomenklatura.store import Store, View
 from nomenklatura.index import Index
 
-__version__ = "2.2.4"
+__version__ = "3.3.3"
 __all__ = [
     "Dataset",
     "CompositeEntity",
     "Resolver",
     "Index",
-    "Loader",
-    "FileLoader",
-    "MemoryLoader",
+    "Store",
+    "View",
 ]
