@@ -1,9 +1,9 @@
 import json
 from typing import Generator
 from followthemoney import model
-from followthemoney.dedupe import Judgement
+from followthemoney.proxy import EntityProxy
 
-from nomenklatura.entity import CompositeEntity
+from nomenklatura.judgement import Judgement
 from nomenklatura.util import PathLike
 
 
@@ -14,7 +14,7 @@ class JudgedPair(object):
     __slots__ = ("left", "right", "judgement")
 
     def __init__(
-        self, left: CompositeEntity, right: CompositeEntity, judgement: Judgement
+        self, left: EntityProxy, right: EntityProxy, judgement: Judgement
     ) -> None:
         self.left = left
         self.right = right
@@ -26,8 +26,8 @@ def read_pairs(pairs_file: PathLike) -> Generator[JudgedPair, None, None]:
     with open(pairs_file, "r") as fh:
         while line := fh.readline():
             data = json.loads(line)
-            left_entity = CompositeEntity.from_data(model, data["left"], {})
-            right_entity = CompositeEntity.from_data(model, data["right"], {})
+            left_entity = EntityProxy.from_dict(model, data["left"])
+            right_entity = EntityProxy.from_dict(model, data["right"])
             judgement = Judgement(data["judgement"])
             if judgement not in (Judgement.POSITIVE, Judgement.NEGATIVE):
                 continue
